==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/LaunchTemplateMaintenanceOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.LaunchTemplateMaintenanceOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property autoRecovery Disables the automatic recovery behavior of your instance or sets it to default. Can be `"default"` or `"disabled"`. See [Recover your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-recover.html) for more details.
 */
public data class LaunchTemplateMaintenanceOptionsArgs(
    public val autoRecovery: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.LaunchTemplateMaintenanceOptionsArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.LaunchTemplateMaintenanceOptionsArgs =
        com.pulumi.aws.ec2.inputs.LaunchTemplateMaintenanceOptionsArgs.builder()
            .autoRecovery(autoRecovery?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LaunchTemplateMaintenanceOptionsArgs].
 */
@PulumiTagMarker
public class LaunchTemplateMaintenanceOptionsArgsBuilder internal constructor() {
    private var autoRecovery: Output<String>? = null

    /**
     * @param value Disables the automatic recovery behavior of your instance or sets it to default. Can be `"default"` or `"disabled"`. See [Recover your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-recover.html) for more details.
     */
    @JvmName("oprcgjxddjlatccw")
    public suspend fun autoRecovery(`value`: Output<String>) {
        this.autoRecovery = value
    }

    /**
     * @param value Disables the automatic recovery behavior of your instance or sets it to default. Can be `"default"` or `"disabled"`. See [Recover your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-recover.html) for more details.
     */
    @JvmName("mnmsirkadjxrpwhd")
    public suspend fun autoRecovery(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoRecovery = mapped
    }

    internal fun build(): LaunchTemplateMaintenanceOptionsArgs = LaunchTemplateMaintenanceOptionsArgs(
        autoRecovery = autoRecovery,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/LaunchTemplateMaintenanceOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.LaunchTemplateMaintenanceOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property autoRecovery Disables the automatic recovery behavior of your instance or sets it to default. Can be `"default"` or `"disabled"`. See [Recover your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-recover.html) for more details.
 */
public data class LaunchTemplateMaintenanceOptionsArgs(
    public val autoRecovery: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.LaunchTemplateMaintenanceOptionsArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.LaunchTemplateMaintenanceOptionsArgs =
        com.pulumi.aws.ec2.inputs.LaunchTemplateMaintenanceOptionsArgs.builder()
            .autoRecovery(autoRecovery?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LaunchTemplateMaintenanceOptionsArgs].
 */
@PulumiTagMarker
public class LaunchTemplateMaintenanceOptionsArgsBuilder internal constructor() {
    private var autoRecovery: Output<String>? = null

    /**
     * @param value Disables the automatic recovery behavior of your instance or sets it to default. Can be `"default"` or `"disabled"`. See [Recover your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-recover.html) for more details.
     */
    @JvmName("kqfhdynqhetfueqt")
    public suspend fun autoRecovery(`value`: Output<String>) {
        this.autoRecovery = value
    }

    /**
     * @param value Disables the automatic recovery behavior of your instance or sets it to default. Can be `"default"` or `"disabled"`. See [Recover your instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-recover.html) for more details.
     */
    @JvmName("ympnsitdtvronlfi")
    public suspend fun autoRecovery(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoRecovery = mapped
    }

    internal fun build(): LaunchTemplateMaintenanceOptionsArgs = LaunchTemplateMaintenanceOptionsArgs(
        autoRecovery = autoRecovery,
    )
}
